instrumenttools.BFlatClarinet
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet

.. autoclass:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BFlatClarinet.BFlatClarinet.BFlatClarinet.__repr__
   :noindex:
